@@ -105,6 +105,19 @@ class ODCSAPI(MethodView):
         else:
             return conf.seconds_to_live
 
+    def _run_schedule_compose(self, compose):
+        """Call schedule_compose with error handling.
+
+        :param Compose compose: instance of odcs.server.models.Compose
+        """
+        try:
+            schedule_compose(compose)
+        except Exception as e:
+            raise RuntimeError(
+                "Can not schedule compose probably due to celery broker issue - %s"
+                % str(e)
+            )
+
     @cors_header()
     def get(self, id):
         """Returns ODCS composes.
@@ -155,7 +168,7 @@ class ODCSAPI(MethodView):
         """Extends the compose expiration time or regenerates expired compose.
 
         :query number id: :ref:`ID<id>` of the compose to update/regenerate.
-        :jsonparam number seconds_to_live: Number of seconds before the compoose expires.
+        :jsonparam number seconds_to_live: Number of seconds before the compose expires.
         :jsonparam list sigkeys: Optional list defining the :ref:`sigkeys<sigkeys>`.
             If not defined, original :ref:`sigkeys<sigkeys>` will be used.
         :jsonparam object source: The JSON object allowing to override the source of compose.
@@ -258,7 +271,7 @@ class ODCSAPI(MethodView):
             db.session.commit()
 
             if CELERY_AVAILABLE and conf.celery_broker_url:
-                schedule_compose(compose)
+                self._run_schedule_compose(compose)
 
             return jsonify(compose.json()), 200
         else:
@@ -287,7 +300,7 @@ class ODCSAPI(MethodView):
     def post(self):
         """Creates new ODCS compose request.
 
-        :jsonparam number seconds_to_live: Number of seconds before the compoose expires.
+        :jsonparam number seconds_to_live: Number of seconds before the compose expires.
         :jsonparam list flags: List of :ref:`compose flags<flags>` defined as strings.
         :jsonparam list arches: List of :ref:`arches<arches>` the compose should be generated for.
         :jsonparam list multilib_arches: List of :ref:`multilib arches<multilib_arches>`.
@@ -573,7 +586,7 @@ class ODCSAPI(MethodView):
         db.session.commit()
 
         if CELERY_AVAILABLE and conf.celery_broker_url:
-            schedule_compose(compose)
+            self._run_schedule_compose(compose)
 
         return jsonify(compose.json()), 200
 
@@ -637,7 +650,14 @@ class ODCSAPI(MethodView):
         # change compose.time_to_expire to now, so backend will
         # delete this compose as it's an expired compose now
         compose.time_to_expire = datetime.datetime.utcnow()
-        compose.removed_by = g.user.username
+        try:
+            compose.removed_by = g.user.username
+        except AttributeError:
+            compose.removed_by = "anonymous"
+            log.info(
+                "User info could not found, it is removed by %s" % compose.removed_by
+            )
+
         db.session.add(compose)
         db.session.commit()
         message = (
