@@ -578,6 +578,11 @@ class TestBackend(ModelsBaseTest):
         db.session.add(c)
         db.session.commit()
 
+        reused_c = get_reusable_compose(c)
+        self.assertIsNone(reused_c)
+
+        old_c.state_reason = "Compose is generating"
+        db.session.commit()
         reused_c = get_reusable_compose(c)
         self.assertEqual(reused_c, old_c)
 
@@ -1669,6 +1674,7 @@ class TestGeneratePungiCompose(ModelsBaseTest):
         c.pungi_compose_id = "compose-1-10-2020110.n.0"
         c.id = 1
         c.koji_event = 123456
+        c.label = "Alpha-0.1"
 
         fake_raw_config_urls = {
             "pungi_cfg": {
@@ -1702,6 +1708,12 @@ class TestGeneratePungiCompose(ModelsBaseTest):
                     "../odcs-1",
                     AnyStringWith("/test_composes/production/latest-compose-1"),
                 ),
+                call(
+                    "../odcs-1",
+                    AnyStringWith(
+                        "/test_composes/production/latest-compose-1-Alpha-0.1"
+                    ),
+                ),
             ]
         )
         unlink.assert_called_with(
