@@ -443,6 +443,7 @@ class TestPungi(ModelsBaseTest):
         self.compose.compose_type = "test"
         self.compose.label = None
         self.compose.pungi_config_dump = None
+        self.compose.respin_of = None
 
         makedirs(self.compose.toplevel_dir)
 
@@ -514,6 +515,36 @@ class TestPungi(ModelsBaseTest):
             stdout=AnyStringWith("pungi-stdout.log"),
         )
 
+    @patch("odcs.server.utils.execute_cmd")
+    def test_pungi_run_respin_of(self, execute_cmd):
+        self.compose.respin_of = "Fedora-1-1"
+        pungi_cfg = PungiConfig(
+            "MBS-512", "1", PungiSourceType.MODULE, "testmodule:master:1:1"
+        )
+        pungi = Pungi(1, pungi_cfg)
+        pungi.run(self.compose)
+
+        self.makedirs.assert_called_with(AnyStringWith("test_composes/odcs-1/"))
+        self.makedirs.assert_called_with(AnyStringWith("work/global"))
+        self.ci_dump.assert_called_once_with(
+            AnyStringWith("work/global/composeinfo-base.json")
+        )
+
+        execute_cmd.assert_called_once_with(
+            [
+                "pungi-koji",
+                AnyStringWith("pungi.json"),
+                "--no-latest-link",
+                AnyStringWith("--compose-dir="),
+                "--test",
+                "--respin-of=Fedora-1-1",
+            ],
+            cwd=AnyStringWith("/tmp/"),
+            timeout=3600,
+            stderr=AnyStringWith("pungi-stderr.log"),
+            stdout=AnyStringWith("pungi-stdout.log"),
+        )
+
     @patch("odcs.server.utils.execute_cmd")
     @patch("odcs.server.pungi.PyConfigParser")
     def test_pungi_run_cts(self, py_config_parser, execute_cmd):
@@ -892,6 +923,8 @@ class TestRawPungiConfig(ModelsBaseTest):
                     pungi_conf = json.load(fd)
                 for key in config.keys():
                     self.assertEqual(pungi_conf[key], config[key])
+                # Test that raw_config_wrapper really updated the pungi config.
+                self.assertEqual(pungi_conf["koji_profile"], "odcs_stg")
             finally:
                 shutil.rmtree(td)
 
